#
# spec file for package lua-language-server
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021 Andreas Schneider <asn@cryptomilk.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lua-language-server
Version:        3.7.4
Release:        1.5
Summary:        Lua Language Server coded by Lua
License:        MIT
URL:            https://github.com/LuaLS/lua-language-server
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}-submodules.zip
Source1:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz
Source2:        lua-lsp-launcher.sh
Source3:        README.suse-maint.md
# PATCH-FIX-UPSTREAM time_includes.patch gh#sumneko/lua-language-server#1377 mcepl@suse.com
# Add missing #include
# Patch0:         time_includes.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  ninja
BuildRequires:  unzip
ExcludeArch:    s390x ppc64le ppc64

%description
This package provides a Language Server Protocol (LSP) implementation for Lua.

%prep
%autosetup -c

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"

ninja -C 3rd/luamake -f compile/ninja/linux.ninja
./3rd/luamake/luamake all

%install
install -d -m 0755 %{buildroot}%{_libexecdir}/%{name}
cp -av bin/* %{buildroot}%{_libexecdir}/%{name}

install -d -m 0755 %{buildroot}%{_datadir}/%{name}
cp -av \
    debugger.lua \
    main.lua \
    locale \
    script \
    meta \
    %{buildroot}%{_datadir}/%{name}/

install -d -m 0755 %{buildroot}%{_bindir}
sed -e 's#@LIBEXECDIR@#%{_libexecdir}#' %{SOURCE2} > %{buildroot}%{_bindir}/%{name}
chmod 0755 %{buildroot}%{_bindir}/%{name}

%fdupes %{buildroot}%{_libexecdir}/%{name} %{buildroot}%{_datadir}/%{name}

%check
./3rd/luamake/luamake bee-test unit-test

%files
%license LICENSE
%doc README.md changelog.md
%{_bindir}/%{name}
%{_libexecdir}/%{name}/
%{_datadir}/%{name}/

%changelog
* Fri Jan  5 2024 Kyle Scheuing <kyle@kylescheuing.com>
- Upgrade to 3.7.4:
  - fix: doc.type.function resolve only existing arg.extends
  - Add a rawdesc field to exported docs
  - support c like comments
  - translated some options to zh-cn
* Sun Dec 31 2023 Kyle Scheuing <kyle@kylescheuing.com>
- Upgrade to 3.7.3:
  - fix: can not infer arg type in some cases
* Sat Apr  1 2023 Matej Cepl <mcepl@suse.com>
- Upgrade to 3.6.18:
  - Make functions in string api accept numbers
  - Don't override lm.bindir and lm.EXE_DIR in make.lua
  - add: description for config.addonManager.enable
  - Don't override lm.bindir and lm.EXE_DIR in make.lua
  - add: description for config.addonManager.enable
  - add: addon manager setting to template
  - README updates
  - Array of a class type does not get completion
  - Improve math.abs annotation
  - meta: newproxy can accept a userdata value
* Mon Feb 13 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 3.6.11:
  * https://github.com/sumneko/lua-language-server/blob/3.6.11/changelog.md
    or packaged changelog.md
* Thu Jan 26 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 3.6.7:
  * https://github.com/sumneko/lua-language-server/blob/3.6.7/changelog.md
    or packaged changelog.md
- Added %%check section
- Moved lua-language-server binary to /usr/libexec
* Sat Sep 24 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 3.5.6:
  * fix #1506
  * meta template: luajit add cdata type
  * fix #1537
  * Replace old variable return syntax
  * fix: string.match return type
  * string.find returns any for now
  * update submodules
  * update 3rd-api
- Remove time_includes.patch
* Tue Jul 26 2022 Matej Cepl <mcepl@suse.com>
- Update to 3.5.0:
  - meta: openresty add api run_worker_thread
  - bugfix:allow get() in sharedict return value and nil
  - table new/clear function actual use scenarios
  - #1325: add missing paramter type for getfenv
  - Meta: make osdate accept strings
  - More tag descriptions
  - fix typos in annotation
- Update to 3.4.1:
  - Fix dofile returns multiple values ---@return any ...
  - add 3rd luafilesystem
  - OpenResty type annotation updates
  - fixing grammar in error message
- Add time_includes.patch to fix missing #includes
  (gh#sumneko/lua-language-server#1377).
* Wed Jun 29 2022 Matej Cepl <mcepl@suse.com>
- Update to 3.4.0:
  - NEW diagnostics:
    cast-local-type
    assign-type-mismatch
    param-type-mismatch
    unknown-cast-variable
    cast-type-mismatch
    missing-return-value
    redundant-return-value
    missing-return
    return-type-mismatch
  - NEW settings:
    diagnostics.groupSeverity
    diagnostics.groupFileStatus
    type.castNumberToInteger
    type.weakUnionCheck
    hint.semicolon
  - CHG infer nil as redundant return value
    local function f() end
    local x = f() -- `x` is `nil` instead of `unknown`
  - CHG infer called function by params num
  - --@overload fun(x: number, y: number):string
  - --@overload fun(x: number):number
  - --@return boolean
    local function f() end
    local n1 = f()     -- `n1` is `boolean`
    local n2 = f(0)    -- `n2` is `number`
    local n3 = f(0, 0) -- `n3` is `string`
  - CHG semicolons and parentheses can be used in DocTable
  - --@type { (x: number); (y: boolean) }
    CHG return names and parentheses can be used in DocFunction
  - --@type fun():(x: number, y: number, ...: number)
  - CHG supports ---@return boolean ...
  - CHG improve experience for diagnostics and semantic-tokens
  - FIX diagnostics flash when opening a file
  - FIX sometimes workspace diagnostics are not triggered
- Update to 3.3.0:
  - NEW LuaDoc supports `CODE`
  - --@type `CONST.X` | `CONST.Y`
    local x
    if x == -- suggest `CONST.X` and `CONST.Y` here
  - CHG infer type by error
  - --@type integer|nil
    local n
    if not n then
    error('n is nil')
    end
    print(n) -- `n` is `integer` here
  - CHG infer type by t and t.x
  - --@type table|nil
    local t
    local s = t and t.x or 1 -- `t` in `t.x` is `table`
  - CHG infer type by type(x)
    local x
    if type(x) == 'string' then
    print(x) -- `x` is `string` here
    end
    local tp = type(x)
    if tp == 'boolean' then
    print(x) -- `x` is `boolean` here
    end
  - CHG infer type by >/</>=/<=
    FIX with clients that support LSP 3.17 (VSCode), workspace
    diagnostics are triggered every time when opening a file.
    FIX #1204
    FIX #1208
- Update to 3.2.5:
  - NEW provide config docs in LUA_LANGUAGE_SERVER/doc/
* Sat May 28 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 3.2.4:
  * Include files required to compile by @sharksforarms in #1157
  * NEW settings:
  - workspace.supportScheme: ["file", "untitled", "git"]
  - diagnostics.disableScheme: ["git"]
  * NEW folding: support folding ---@alias
  * CHG if rootUri or workspaceFolder is set to ROOT or HOME, this extension will refuse to load these directories and show an error message.
  * CHG show warning message when scanning more than 100,000 files.
  * CHG upgrade LSP to 3.17
  * FIX hover: can not union table with other basic types
  * FIX #1125
  * FIX #1131
  * FIX #1134
  * FIX #1141
  * FIX #1144
  * FIX #1150
  * FIX #1155
* Mon Apr 11 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 3.0.1:
  * FIX #1033
  * FIX #1034
  * FIX #1035
  * FIX #1036
  * FIX runtime errors reported by telemetry, see #1037
* Mon Apr 11 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 3.0.0:
  * fix(completion): push (#1022) to 3.0 by @kevinhwang91 in #1026
  * fixed #976 by @xiyaowong in #983
  * Ensure that a completion result has 'isIncomplete' by @yoshi1123 in #995
  * update meta basic.lua by @fesily in #1004
  * fix(semantic-tokens): coreect token type priority by @kevinhwang91 in #1009
  * Event emitter support fix by @Cassolette in #1011
  * fix meta debuginfo in jit version by @fesily in #1007
  * chore(editorconfig): use lf for end_of_line by @kevinhwang91 in #1010
  * feat(completion): truncate arguments for callSnippet by @kevinhwang91
    in #1014
  * fix(completion): use args table instead of args string to parse snippet
    by @kevinhwang91 in #1016
  * fix(completion): avoid unnecessary file sep as trigger chars by
    @kevinhwang91 in #1017
  * fix(completion): limit extra lines by @kevinhwang91 in #1019
  * fix(files): check uri whether equal or not by @kevinhwang91 in #1020
  * chore(postfix): pretty postfix description by @kevinhwang91 in #1021
  * feat(completion): use Lua code as snippet description by @kevinhwang91
    in #1022
  * FIX #1023 by @CppCXY in #1024
* Thu Feb 10 2022 Matej Cepl <mcepl@suse.com>
- Update to version 2.6.4:
  * fix(semantic-tokens): limit comments range
  * fix(semantic-tokens): data field can't be nil
  * Fix regular expression to find root directory in
    make/bootstrap.lua
  * feat(postfix): add templates
* Mon Jan 24 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 2.6.1:
  * update ngx/openresty annotations
  * add more skynet function defines
  * Build for linux-arm64
  * add skynet sc and mongo desc
* Tue Dec 28 2021 Matej Cepl <mcepl@suse.com>
- With help of upstream, I finally found the released upstream
  zip archive.
* Mon Dec 27 2021 Matej Cepl <mcepl@suse.com>
- Update to version 2.5.6:
  - chore: update lua-resty-websocket library annotations
  - Update OpenResty typedefs, annotations, and configuration
* Fri Dec 17 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 2.5.5
  * FIX does not work in VSCode
* Thu Dec 16 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 2.5.4
  o 2.5.4
  * `FIX` [#847](https://github.com/sumneko/lua-language-server/issues/847)
  * `FIX` [#848](https://github.com/sumneko/lua-language-server/issues/848)
  * `FIX` completion: incorrect cache
  * `FIX` hover: always view string
  o 2.5.3
  * `FIX` [#842](https://github.com/sumneko/lua-language-server/issues/844)
  * `FIX` [#844](https://github.com/sumneko/lua-language-server/issues/844)
  o 2.5.2
  * `FIX` [#815](https://github.com/sumneko/lua-language-server/issues/815)
  * `FIX` [#825](https://github.com/sumneko/lua-language-server/issues/825)
  * `FIX` [#826](https://github.com/sumneko/lua-language-server/issues/826)
  * `FIX` [#827](https://github.com/sumneko/lua-language-server/issues/827)
  * `FIX` [#831](https://github.com/sumneko/lua-language-server/issues/831)
  * `FIX` [#837](https://github.com/sumneko/lua-language-server/issues/837)
  * `FIX` [#838](https://github.com/sumneko/lua-language-server/issues/838)
  * `FIX` postfix
  * `FIX` runtime errors
  o 2.5.1
  * `FIX` incorrect syntax error
  o 2.5.0
  * `NEW` settings:
    + `Lua.runtime.pathStrict`: not check subdirectories when using `runtime.path`
    + `Lua.hint.await`: display `await` when calling a function marked as async
    + `Lua.completion.postfix`: the symbol that triggers postfix, default is `@`
  * `NEW` add supports for `lovr`
  * `NEW` file encoding supports `utf16le` and `utf16be`
  * `NEW` full IntelliSense supports for literal tables, see [#720](https://github.com/sumneko/lua-language-server/issues/720) and [#727](https://github.com/sumneko/lua-language-server/issues/727)
  * `NEW` `LuaDoc` annotations:
    + `---@async`: mark a function as async
    + `---@nodiscard`: the return value of the marking function cannot be discarded
  * `NEW` diagnostics:
    + `await-in-sync`: check whether calls async function in sync function. disabled by default.
    + `not-yieldable`: check whether the function supports async functions as parameters. disabled by default.
    + `discard-returns`: check whether the return value is discarded.
  * `NEW` locale `pt-br`, thanks [Jeferson Ferreira](https://github.com/jefersonf)
  * `NEW` supports [utf-8-offsets](https://clangd.llvm.org/extensions#utf-8-offsets)
  * `NEW` supports quickfix for `.luarc.json`
  * `NEW` completion postifx: `@function`, `@method`, `@pcall`, `@xpcall`, `@insert`, `@remove`, `@concat`, `++`, `++?`
  * `CHG` `LuaDoc`:
    + `---@class` can be re-declared
    + supports unicode
    + supports `---@param ... number`, equivalent to `---@vararg number`
    + supports `fun(...: string)`
    + supports `fun(x, y, ...)`, equivalent to `fun(x: any, y: any, ...: any)`
  * `CHG` settings from `--configpath`, `.luarc.json`, `client` no longer prevent subsequent settings, instead they are merged in order
  * `CHG` no longer asks to trust plugin in VSCode, because VSCode already provides the workspace trust feature
  * `CHG` skip huge files (>= 10 MB)
  * `CHG` after using `Lua.runtime.nonstandardSymbol` to treat `//` as a comment, `//` is no longer parsed as an operator
  o 2.4.11
  * `FIX` [#816](https://github.com/sumneko/lua-language-server/issues/816)
  * `FIX` [#817](https://github.com/sumneko/lua-language-server/issues/817)
  * `FIX` [#818](https://github.com/sumneko/lua-language-server/issues/818)
  * `FIX` [#820](https://github.com/sumneko/lua-language-server/issues/820)
  o 2.4.10
  * `FIX` [#790](https://github.com/sumneko/lua-language-server/issues/790)
  * `FIX` [#798](https://github.com/sumneko/lua-language-server/issues/798)
  * `FIX` [#804](https://github.com/sumneko/lua-language-server/issues/804)
  * `FIX` [#805](https://github.com/sumneko/lua-language-server/issues/805)
  * `FIX` [#806](https://github.com/sumneko/lua-language-server/issues/806)
  * `FIX` [#807](https://github.com/sumneko/lua-language-server/issues/807)
  * `FIX` [#809](https://github.com/sumneko/lua-language-server/issues/809)
  o 2.4.9
  * `CHG` for performance reasons, some of the features that are not cost-effective in IntelliSense have been disabled by default, and you can re-enable them through the following settings:
    + `Lua.IntelliSense.traceLocalSet`
    + `Lua.IntelliSense.traceReturn`
    + `Lua.IntelliSense.traceBeSetted`
    + `Lua.IntelliSense.traceFieldInject`
  o 2.4.8
  * `FIX` incorrect IntelliSense in specific situations
  * `FIX` [#777](https://github.com/sumneko/lua-language-server/issues/777)
  * `FIX` [#778](https://github.com/sumneko/lua-language-server/issues/778)
  * `FIX` [#779](https://github.com/sumneko/lua-language-server/issues/779)
  * `FIX` [#780](https://github.com/sumneko/lua-language-server/issues/780)
  o 2.4.7
  * `FIX` [#762](https://github.com/sumneko/lua-language-server/issues/762)
  o 2.4.6
  * `NEW` diagnostic: `redundant-return`
  * `FIX` [#744](https://github.com/sumneko/lua-language-server/issues/744)
  * `FIX` [#748](https://github.com/sumneko/lua-language-server/issues/748)
  * `FIX` [#749](https://github.com/sumneko/lua-language-server/issues/749)
  * `FIX` [#752](https://github.com/sumneko/lua-language-server/issues/752)
  * `FIX` [#753](https://github.com/sumneko/lua-language-server/issues/753)
  * `FIX` [#756](https://github.com/sumneko/lua-language-server/issues/756)
  * `FIX` [#758](https://github.com/sumneko/lua-language-server/issues/758)
  * `FIX` [#760](https://github.com/sumneko/lua-language-server/issues/760)
  o 2.4.5
  `2021-10-18`
  * `FIX` accidentally load lua files from user workspace
  o 2.4.4
  * `CHG` improve `.luarc.json`
  * `FIX` [#722](https://github.com/sumneko/lua-language-server/issues/722)
  o 2.4.3
  * `FIX` [#713](https://github.com/sumneko/lua-language-server/issues/713)
  * `FIX` [#718](https://github.com/sumneko/lua-language-server/issues/718)
  * `FIX` [#719](https://github.com/sumneko/lua-language-server/issues/719)
  * `FIX` [#725](https://github.com/sumneko/lua-language-server/issues/725)
  * `FIX` [#729](https://github.com/sumneko/lua-language-server/issues/729)
  * `FIX` [#730](https://github.com/sumneko/lua-language-server/issues/730)
  * `FIX` runtime errors
  o 2.4.2
  * `FIX` [#702](https://github.com/sumneko/lua-language-server/issues/702)
  * `FIX` [#706](https://github.com/sumneko/lua-language-server/issues/706)
  * `FIX` [#707](https://github.com/sumneko/lua-language-server/issues/707)
  * `FIX` [#709](https://github.com/sumneko/lua-language-server/issues/709)
  * `FIX` [#712](https://github.com/sumneko/lua-language-server/issues/712)
  o 2.4.1
  * `FIX` broken with single file
  * `FIX` [#698](https://github.com/sumneko/lua-language-server/issues/698)
  * `FIX` [#699](https://github.com/sumneko/lua-language-server/issues/699)
  o 2.4.0
  * `NEW` loading settings from `.luarc.json`
  * `NEW` settings:
    + `Lua.diagnostics.libraryFiles`
    + `Lua.diagnostics.ignoredFiles`
    + `Lua.completion.showWord`
    + `Lua.completion.requireSeparator`
  * `NEW` diagnostics:
    + `different-requires`
  * `NEW` `---@CustomClass<string, number>`
  * `NEW` supports `$/cancelRequest`
  * `NEW` `EventEmitter`
    ```lua
  - -- @class Emit
  - -- @field on fun(eventName: string, cb: function)
  - -- @field on fun(eventName: '"died"', cb: fun(i: integer))
  - -- @field on fun(eventName: '"won"', cb: fun(s: string))
    local emit = {}
    emit:on(--[[support autocomplete fr "died" and "won"]])
    emit:on("died", function (i)
  - - should be i: integer
    end)
    emit:on('won', function (s)
  - - should be s: string
    end)
    ```
  * `NEW` `---@module 'moduleName'`
    ```lua
  - --@module 'mylib'
    local lib -- the same as `local lib = require 'mylib'`
    ```
  * `NEW` add supports of `skynet`
  * `CHG` hover: improve showing multi defines
  * `CHG` hover: improve showing multi comments at enums
  * `CHG` hover: shows method
  * `CHG` hint: `Lua.hint.paramName` now supports `Disable`, `Literal` and `All`
  * `CHG` only search first file by `require`
  * `CHG` no longer infer by usage
  * `CHG` no longer ignore file names case in Windows
  * `CHG` watching library changes
  * `CHG` completion: improve misspelling results
  * `CHG` completion: `Lua.completion.displayContext` default to `0`
  * `CHG` completion: `autoRequire` has better inserting position
  * `CHG` diagnostics:
    + `redundant-parameter` default severity to `Warning`
    + `redundant-value` default severity to `Warning`
  * `CHG` infer: more strict of calculation results
  * `CHG` [#663](https://github.com/sumneko/lua-language-server/issues/663)
  * `FIX` runtime errors
  * `FIX` hint: may show param-2 as `self`
  * `FIX` semantic: may fail when scrolling
  * `FIX` [#647](https://github.com/sumneko/lua-language-server/issues/647)
  * `FIX` [#660](https://github.com/sumneko/lua-language-server/issues/660)
  * `FIX` [#673](https://github.com/sumneko/lua-language-server/issues/673)
  o 2.3.7
  * `CHG` improve performance
  * `FIX` [#244](https://github.com/sumneko/lua-language-server/issues/244)
  o 2.3.6
  * `FIX` completion: can not find global fields
  * `FIX` globals and class may lost
  o 2.3.5
  * `CHG` improve memory usage
  * `CHG` completion: call snip triggers signature (VSCode only)
  * `FIX` completion: may not find results
  o 2.3.4
  * `CHG` improve performance
  * `FIX` [#625](https://github.com/sumneko/lua-language-server/issues/625)
  o 2.3.3
  * `NEW` config supports prop
  * `FIX` [#612](https://github.com/sumneko/lua-language-server/issues/612)
  * `FIX` [#613](https://github.com/sumneko/lua-language-server/issues/613)
  * `FIX` [#618](https://github.com/sumneko/lua-language-server/issues/618)
  * `FIX` [#620](https://github.com/sumneko/lua-language-server/issues/620)
  o 2.3.2
  * `NEW` `LuaDoc`: supports `['string']` as field:
    ```lua
  - --@class keyboard
  - --@field ['!'] number
  - --@field ['?'] number
  - --@field ['#'] number
    ```
  * `NEW` add supports of `love2d`
  * `FIX` gitignore pattern `\` broken initialization
  * `FIX` runtime errors
  o 2.3.1
  * `NEW` setting `Lua.workspace.userThirdParty`, add private user [third-parth](https://github.com/sumneko/lua-language-server/tree/master/meta/3rd) by this setting
  * `CHG` path in config supports `~/xxxx`
  * `FIX` `autoRequire` inserted incorrect code
  * `FIX` `autoRequire` may provide dumplicated options
  * `FIX` [#606](https://github.com/sumneko/lua-language-server/issues/606)
  * `FIX` [#607](https://github.com/sumneko/lua-language-server/issues/607)
- Removed obsolete fix_i586_test.patch
* Fri Jul 16 2021 Matej Cepl <mcepl@suse.com>
- Add fix_i586_test.patch to switch off testing architecture in bee.lua
* Fri Jul 16 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 2.3.0
  - https://github.com/sumneko/lua-language-server/blob/2.3.0/changelog.md
- Use obs_scm in _service file (tar_scm is deprecated)
* Thu Jul 15 2021 Andreas Schneider <asn@cryptomilk.org>
- Initial package
